@@ -6,42 +6,35 @@
  *
  */
 
-#ifndef __ATHEME_OBJECT_H__
-#define __ATHEME_OBJECT_H__
+#ifndef ATHEME_OBJECT_H
+#define ATHEME_OBJECT_H
 
 struct metadata_ {
-	char *name;
+	stringref name;
 	char *value;
-	bool private;
-	mowgli_node_t node;
 };
 
 typedef struct metadata_ metadata_t;
 
-typedef struct {
-	myuser_t *mu;
-	mowgli_list_t taglist;
-} metadata_subscription_t;
-
 typedef void (*destructor_t)(void *);
 
 typedef struct {
-	char *name;
-#ifdef USE_OBJECT_REF
 	int refcount;
-#endif
 	destructor_t destructor;
-	mowgli_list_t metadata;
+	mowgli_patricia_t *metadata;
 	mowgli_patricia_t *privatedata;
+#ifdef OBJECT_DEBUG
+	mowgli_node_t dnode;
+#endif
 } object_t;
 
 E void init_metadata(void);
 
 E void object_init(object_t *, const char *name, destructor_t destructor);
-#ifdef USE_OBJECT_REF
 E void *object_ref(void *);
-#endif
+E void *object_sink_ref(void *);
 E void object_unref(void *);
+E void object_dispose(void *);
 
 E metadata_t *metadata_add(void *target, const char *name, const char *value);
 E void metadata_delete(void *target, const char *name);
@@ -51,6 +44,10 @@ E void metadata_delete_all(void *target);
 E void *privatedata_get(void *target, const char *key);
 E void privatedata_set(void *target, const char *key, void *data);
 
+#ifdef OBJECT_DEBUG
+E mowgli_list_t object_list;
+#endif
+
 #define object(x) ((object_t *) x)
 
 #endif
