@@ -7,20 +7,21 @@
  *
  */
 
-#ifndef _UPLINK_H
-#define _UPLINK_H
+#ifndef ATHEME_UPLINK_H
+#define ATHEME_UPLINK_H
 
 typedef struct uplink_ uplink_t;
 
 struct uplink_
 {
+	mowgli_node_t	node;
+
 	char *name;
 	char *host;
-	char *pass;
+	char *send_pass;
+	char *receive_pass;
 	char *vhost;
 
-	mowgli_node_t	*node;
-
 	unsigned int port;
 
 	connection_t *conn;
@@ -35,7 +36,7 @@ E mowgli_list_t uplinks;
 E uplink_t *curr_uplink;
 
 E void init_uplinks(void);
-E uplink_t *uplink_add(const char *name, const char *host, const char *password, const char *vhost, int port);
+E uplink_t *uplink_add(const char *name, const char *host, const char *send_password, const char *receive_password, const char *vhost, int port);
 E void uplink_delete(uplink_t *u);
 E uplink_t *uplink_find(const char *name);
 E void uplink_connect(void);
@@ -46,12 +47,8 @@ E void uplink_connect(void);
 E struct timeval burstime;
 #endif
 
-E void irc_handle_connect(connection_t *cptr);
-
-/* parse.c */
 E void (*parse)(char *line);
-E void irc_parse(char *line);
-E void p10_parse(char *line);
+E void irc_handle_connect(connection_t *cptr);
 
 /* send.c */
 E int sts(const char *fmt, ...) PRINTFLIKE(1, 2);
