@@ -5,7 +5,7 @@
  * Structs and functions for interacting with JSON documents from C
  */
 
-#include <mowgli.h>
+#include "mowgli.h"
 
 /* TOC:
  * 0. JSON subsystem constants
@@ -46,7 +46,9 @@ static mowgli_json_t json_false =
 };
 mowgli_json_t *mowgli_json_false = &json_false;
 
-static mowgli_json_t *json_alloc(mowgli_json_tag_t tag);
+static mowgli_json_t *json_alloc(mowgli_json_tag_t tag)
+    MOWGLI_FATTR_MALLOC;
+
 static void json_destroy(mowgli_json_t *n);
 static void destroy_extra_string(mowgli_json_t *n);
 static void destroy_extra_array(mowgli_json_t *n);
@@ -142,7 +144,7 @@ json_alloc(mowgli_json_tag_t tag)
 {
 	mowgli_json_t *n;
 
-	n = mowgli_alloc(sizeof(*n));
+	n = mowgli_alloc(sizeof *n);
 
 	n->tag = tag;
 	n->refcount = 0;
@@ -744,7 +746,7 @@ ll_token_alloc(enum ll_sym sym, mowgli_json_t *val)
 {
 	struct ll_token *tok;
 
-	tok = mowgli_alloc(sizeof(*tok));
+	tok = mowgli_alloc(sizeof *tok);
 	tok->sym = sym;
 	tok->val = val;
 
@@ -791,7 +793,7 @@ parse_out_dequeue(mowgli_json_parse_t *parse)
 	return n;
 }
 
-static void
+static void MOWGLI_FATTR_PRINTF(2, 3)
 parse_error(mowgli_json_parse_t *parse, const char *fmt, ...)
 {
 	va_list va;
@@ -1179,12 +1181,12 @@ lex_char(mowgli_json_parse_t *parse, char c)
 		case ',': lex_easy(parse, TS_VALUE_SEP); return false;
 		}
 
-		if ((c == '-') || (c == '.') || isdigit(c))
+		if ((c == '-') || (c == '.') || isdigit((unsigned char)c))
 		{
 			parse->lex = LEX_NUMBER;
 			return true;
 		}
-		else if (isalpha(c))
+		else if (isalpha((unsigned char)c))
 		{
 			parse->lex = LEX_IDENTIFIER;
 			return true;
@@ -1194,7 +1196,7 @@ lex_char(mowgli_json_parse_t *parse, char c)
 			parse->lex = LEX_STRING;
 			return false;
 		}
-		else if (isspace(c))
+		else if (isspace((unsigned char)c))
 		{
 			return false;
 		}
@@ -1248,7 +1250,7 @@ lex_char(mowgli_json_parse_t *parse, char c)
 
 	case LEX_NUMBER:
 
-		if ((c == '-') || (c == '.') || isdigit(c) || (toupper(c) == 'E'))
+		if ((c == '-') || (c == '.') || isdigit((unsigned char)c) || (toupper((unsigned char)c) == 'E'))
 		{
 			lex_append(parse, c);
 			return false;
@@ -1259,11 +1261,9 @@ lex_char(mowgli_json_parse_t *parse, char c)
 			return true;
 		}
 
-		break;
-
 	case LEX_IDENTIFIER:
 
-		if (isalpha(c))
+		if (isalpha((unsigned char)c))
 		{
 			lex_append(parse, c);
 			return false;
@@ -1273,8 +1273,6 @@ lex_char(mowgli_json_parse_t *parse, char c)
 			lex_tokenize(parse);
 			return true;
 		}
-
-		break;
 	}
 
 	/* This should never happen... */
@@ -1287,7 +1285,7 @@ mowgli_json_parse_create(bool multidoc)
 {
 	mowgli_json_parse_t *parse;
 
-	parse = mowgli_alloc(sizeof(*parse));
+	parse = mowgli_alloc(sizeof *parse);
 
 	parse->out = mowgli_list_create();
 	parse->error[0] = '\0';
