@@ -2,7 +2,7 @@
  * libmowgli: A collection of useful routines for programming.
  * module.h: Loadable modules.
  *
- * Copyright (c) 2007 William Pitcock <nenolod -at- sacredspiral.co.uk>
+ * Copyright (c) 2007, 2014 William Pitcock <william@dereferenced.org>
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -21,8 +21,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef __MOWGLI_MODULE_H__
-#define __MOWGLI_MODULE_H__
+#ifndef MOWGLI_SRC_LIBMOWGLI_MODULE_MODULE_H_INCLUDE_GUARD
+#define MOWGLI_SRC_LIBMOWGLI_MODULE_MODULE_H_INCLUDE_GUARD 1
+
+#include "core/stdinc.h"
 
 typedef void *mowgli_module_t;
 
@@ -30,4 +32,15 @@ extern mowgli_module_t mowgli_module_open(const char *path);
 extern void *mowgli_module_symbol(mowgli_module_t module, const char *symbol);
 extern void mowgli_module_close(mowgli_module_t module);
 
-#endif
+typedef void mowgli_interface_t;
+
+typedef struct {
+	const char *id;
+	uint32_t abirev;
+} mowgli_interface_base_t;
+
+extern void mowgli_interface_register(mowgli_interface_t *iface);
+extern void mowgli_interface_unregister(mowgli_interface_t *iface);
+extern mowgli_interface_t *mowgli_interface_get(const char *id, uint32_t abirev);
+
+#endif /* MOWGLI_SRC_LIBMOWGLI_MODULE_MODULE_H_INCLUDE_GUARD */
