@@ -12,7 +12,7 @@ DECLARE_MODULE_V1
 (
 	"auth/dummy", false, _modinit, _moddeinit,
 	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
+	VENDOR_STRING
 );
 
 static bool dummy_auth_user(myuser_t *mu, const char *password)
