@@ -13,7 +13,7 @@ DECLARE_MODULE_V1
 (
 	"chanserv/set_verbose", false, _modinit, _moddeinit,
 	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
+	VENDOR_STRING
 );
 
 static void cs_cmd_set_verbose(sourceinfo_t *si, int parc, char *parv[]);
@@ -69,7 +69,7 @@ static void cs_cmd_set_verbose(sourceinfo_t *si, int parc, char *parv[])
  		mc->flags &= ~MC_VERBOSE_OPS;
  		mc->flags |= MC_VERBOSE;
 
-		verbose(mc, "\2%s\2 enabled the VERBOSE flag", get_source_name(si));
+		verbose(mc, _("\2%s\2 enabled the VERBOSE flag"), get_source_name(si));
 		command_success_nodata(si, _("The \2%s\2 flag has been set for channel \2%s\2."), "VERBOSE", mc->name);
 		return;
 	}
@@ -86,14 +86,14 @@ static void cs_cmd_set_verbose(sourceinfo_t *si, int parc, char *parv[])
 
 		if (mc->flags & MC_VERBOSE)
 		{
-			verbose(mc, "\2%s\2 restricted VERBOSE to chanops", get_source_name(si));
+			verbose(mc, _("\2%s\2 restricted VERBOSE to chanops"), get_source_name(si));
  			mc->flags &= ~MC_VERBOSE;
  			mc->flags |= MC_VERBOSE_OPS;
 		}
 		else
 		{
  			mc->flags |= MC_VERBOSE_OPS;
-			verbose(mc, "\2%s\2 enabled the VERBOSE_OPS flag", get_source_name(si));
+			verbose(mc, _("\2%s\2 enabled the VERBOSE_OPS flag"), get_source_name(si));
 		}
 
 		command_success_nodata(si, _("The \2%s\2 flag has been set for channel \2%s\2."), "VERBOSE_OPS", mc->name);
@@ -110,9 +110,9 @@ static void cs_cmd_set_verbose(sourceinfo_t *si, int parc, char *parv[])
 		logcommand(si, CMDLOG_SET, "SET:VERBOSE:OFF: \2%s\2", mc->name);
 
 		if (mc->flags & MC_VERBOSE)
-			verbose(mc, "\2%s\2 disabled the VERBOSE flag", get_source_name(si));
+			verbose(mc, _("\2%s\2 disabled the VERBOSE flag"), get_source_name(si));
 		else
-			verbose(mc, "\2%s\2 disabled the VERBOSE_OPS flag", get_source_name(si));
+			verbose(mc, _("\2%s\2 disabled the VERBOSE_OPS flag"), get_source_name(si));
 		mc->flags &= ~(MC_VERBOSE | MC_VERBOSE_OPS);
 
 		command_success_nodata(si, _("The \2%s\2 flag has been removed for channel \2%s\2."), "VERBOSE", mc->name);
