@@ -6,18 +6,15 @@
  */
 
 #include "atheme-compat.h"
-#include "conf.h"
 
-DECLARE_MODULE_V1
-(
-	"contrib/cs_regnotice", false, _modinit, _moddeinit,
-        PACKAGE_STRING,
-        "Atheme Development Group <http://www.atheme.org>"
-);
+#if (CURRENT_ABI_REVISION < 730000)
+#  include "conf.h"
+#endif
 
 static mowgli_list_t regnotices = { NULL, NULL, 0 };
 
-static void regnotice_hook(hook_channel_req_t *hdata)
+static void
+regnotice_hook(hook_channel_req_t *hdata)
 {
 	mowgli_node_t *n;
 	sourceinfo_t *si = hdata->si;
@@ -34,7 +31,8 @@ static void regnotice_hook(hook_channel_req_t *hdata)
 	}
 }
 
-static int regnotice_config_handler(mowgli_config_file_entry_t *ce)
+static int
+regnotice_config_handler(mowgli_config_file_entry_t *ce)
 {
 	mowgli_config_file_entry_t *cce;
 
@@ -47,7 +45,8 @@ static int regnotice_config_handler(mowgli_config_file_entry_t *ce)
 	return 0;
 }
 
-static void regnotice_config_purge(void *unused)
+static void
+regnotice_config_purge(void *unused)
 {
 	mowgli_node_t *n, *tn;
 
@@ -55,14 +54,14 @@ static void regnotice_config_purge(void *unused)
 	{
 		char *line = n->data;
 
-		free(line);
+		sfree(line);
 		mowgli_node_delete(n, &regnotices);
 		mowgli_node_free(n);
 	}
 }
 
-void
-_modinit(module_t *m)
+static void
+mod_init(module_t *m)
 {
 	hook_add_event("config_purge");
 	hook_add_config_purge(regnotice_config_purge);
@@ -73,11 +72,13 @@ _modinit(module_t *m)
 	add_conf_item("REGNOTICE", &chansvs.me->conf_table, regnotice_config_handler);
 }
 
-void
-_moddeinit(module_unload_intent_t intent)
+static void
+mod_deinit(module_unload_intent_t intent)
 {
 	hook_del_channel_register(regnotice_hook);
 	hook_del_config_purge(regnotice_config_purge);
 
 	del_conf_item("REGNOTICE", &chansvs.me->conf_table);
 }
+
+SIMPLE_DECLARE_MODULE_V1("contrib/cs_regnotice", MODULE_UNLOAD_CAPABILITY_OK)
