@@ -3,21 +3,14 @@
  * Rights to this code are as documented in doc/LICENSE.
  *
  * LoveServ implementation.
- *
  */
 
 #include "atheme-compat.h"
 
-DECLARE_MODULE_V1
-(
-        "contrib/ircd_loveserv", false, _modinit, _moddeinit,
-        PACKAGE_STRING,
-        "Atheme Development Group <http://www.atheme.org>"
-);
+static service_t *loveserv = NULL;
 
-service_t *loveserv;
-
-static void _ls_admirer(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_admirer(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -38,9 +31,8 @@ static void _ls_admirer(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "You have a secret admirer ;)");
 }
 
-command_t ls_admirer = { "ADMIRER", "Tell somebody they have a secret admirer.", AC_NONE, 1, _ls_admirer, { .path = "" } };
-
-static void _ls_rose(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_rose(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -61,9 +53,8 @@ static void _ls_rose(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s has sent you a pretty rose: \00303--<--<--<{\00304@", si->su->nick);
 }
 
-command_t ls_rose = { "ROSE", "Sends a rose to somebody.", AC_NONE, 1, _ls_rose, { .path = "" } };
-
-static void _ls_chocolate(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_chocolate(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -84,9 +75,8 @@ static void _ls_chocolate(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s would like you to have this YUMMY box of chocolates.", si->su->nick);
 }
 
-command_t ls_chocolate = { "CHOCOLATE", "Sends chocolates to somebody.", AC_NONE, 1, _ls_chocolate, { .path = "" } };
-
-static void _ls_candy(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_candy(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -107,9 +97,8 @@ static void _ls_candy(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s would like you to have this bag of heart-shaped candies.", si->su->nick);
 }
 
-command_t ls_candy = { "CANDY", "Sends a bag of candy to somebody.", AC_NONE, 1, _ls_candy, { .path = "" } };
-
-static void _ls_hug(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_hug(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -130,9 +119,8 @@ static void _ls_hug(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s has sent you a \002BIG WARM HUG\002.", si->su->nick);
 }
 
-command_t ls_hug = { "HUG", "Reach out and hug somebody.", AC_NONE, 1, _ls_hug, { .path = "" } };
-
-static void _ls_kiss(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_kiss(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -153,9 +141,8 @@ static void _ls_kiss(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s has sent you a \00304kiss\003.", si->su->nick);
 }
 
-command_t ls_kiss = { "KISS", "Kiss somebody.", AC_NONE, 1, _ls_kiss, { .path = "" } };
-
-static void _ls_lovenote(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_lovenote(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 	char *note = parv[1];
@@ -177,9 +164,8 @@ static void _ls_lovenote(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s has sent you a love-note which reads: %s", si->su->nick, note);
 }
 
-command_t ls_lovenote = { "LOVENOTE", "Sends a lovenote to somebody.", AC_NONE, 2, _ls_lovenote, { .path = "" } };
-
-static void _ls_apology(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_apology(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 	char *note = parv[1];
@@ -201,9 +187,8 @@ static void _ls_apology(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s would like to apologize for: %s", si->su->nick, note);
 }
 
-command_t ls_apology = { "APOLOGY", "Sends an apology to somebody.", AC_NONE, 2, _ls_apology, { .path = "" } };
-
-static void _ls_thankyou(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_thankyou(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 	char *note = parv[1];
@@ -225,9 +210,8 @@ static void _ls_thankyou(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s would like to thank you for: %s", si->su->nick, note);
 }
 
-command_t ls_thankyou = { "THANKYOU", "Sends a thank-you note to somebody.", AC_NONE, 2, _ls_thankyou, { .path = "" } };
-
-static void _ls_spank(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_spank(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 
@@ -248,9 +232,8 @@ static void _ls_spank(sourceinfo_t *si, int parc, char *parv[])
 	notice(loveserv->nick, target, "%s has given you a virtual playful spanking.", si->su->nick);
 }
 
-command_t ls_spank = { "SPANK", "Gives somebody a spanking.", AC_NONE, 1, _ls_spank, { .path = "" } };
-
-static void _ls_chocobo(sourceinfo_t *si, int parc, char *parv[])	/* silly */
+static void
+_ls_chocobo(sourceinfo_t *si, int parc, char *parv[])	/* silly */
 {
 	char *target = parv[0];
 
@@ -271,19 +254,124 @@ static void _ls_chocobo(sourceinfo_t *si, int parc, char *parv[])	/* silly */
 	notice(loveserv->nick, target, "%s would like you to have this chocobo. \00308Kweh!\003", si->su->nick);
 }
 
-command_t ls_chocobo = { "CHOCOBO", "Sends a chocobo to somebody.", AC_NONE, 1, _ls_chocobo, { .path = "" } };
-
-static void _ls_help(sourceinfo_t *si, int parc, char *parv[])
+static void
+_ls_help(sourceinfo_t *si, int parc, char *parv[])
 {
         command_help(si, si->service->commands);
 }
 
-command_t ls_help = { "HELP", "Displays contextual help information.",
-                                AC_NONE, 1, _ls_help, { .path = "help" } };
+static command_t ls_admirer = {
+	"ADMIRER",
+	N_("Tell somebody they have a secret admirer."),
+	AC_NONE,
+	1,
+	&_ls_admirer,
+	{ .path = "" },
+};
 
-void _modinit(module_t *m)
+static command_t ls_rose = {
+	"ROSE",
+	N_("Sends a rose to somebody."),
+	AC_NONE,
+	1,
+	&_ls_rose,
+	{ .path = "" },
+};
+
+static command_t ls_chocolate = {
+	"CHOCOLATE",
+	N_("Sends chocolates to somebody."),
+	AC_NONE,
+	1,
+	&_ls_chocolate,
+	{ .path = "" },
+};
+
+static command_t ls_candy = {
+	"CANDY",
+	N_("Sends a bag of candy to somebody."),
+	AC_NONE,
+	1,
+	&_ls_candy,
+	{ .path = "" },
+};
+
+static command_t ls_hug = {
+	"HUG",
+	N_("Reach out and hug somebody."),
+	AC_NONE,
+	1,
+	&_ls_hug,
+	{ .path = "" },
+};
+
+static command_t ls_kiss = {
+	"KISS",
+	N_("Kiss somebody."),
+	AC_NONE,
+	1,
+	&_ls_kiss,
+	{ .path = "" },
+};
+
+static command_t ls_lovenote = {
+	"LOVENOTE",
+	N_("Sends a lovenote to somebody."),
+	AC_NONE,
+	2,
+	&_ls_lovenote,
+	{ .path = "" },
+};
+
+static command_t ls_apology = {
+	"APOLOGY",
+	N_("Sends an apology to somebody."),
+	AC_NONE,
+	2,
+	&_ls_apology,
+	{ .path = "" },
+};
+
+static command_t ls_thankyou = {
+	"THANKYOU",
+	N_("Sends a thank-you note to somebody."),
+	AC_NONE,
+	2,
+	&_ls_thankyou,
+	{ .path = "" },
+};
+
+static command_t ls_spank = {
+	"SPANK",
+	N_("Gives somebody a spanking."),
+	AC_NONE,
+	1,
+	&_ls_spank,
+	{ .path = "" },
+};
+
+static command_t ls_chocobo = {
+	"CHOCOBO",
+	N_("Sends a chocobo to somebody."),
+	AC_NONE,
+	1,
+	&_ls_chocobo,
+	{ .path = "" },
+};
+
+static command_t ls_help = {
+	"HELP",
+	N_("Displays contextual help information."),
+	AC_NONE,
+	1,
+	&_ls_help,
+	{ .path = "help" },
+};
+
+static void
+mod_init(module_t *const restrict m)
 {
-        loveserv = service_add("LoveServ", NULL);
+        loveserv = service_add("loveserv", NULL);
 
 	service_bind_command(loveserv, &ls_admirer);
 	service_bind_command(loveserv, &ls_rose);
@@ -299,7 +387,8 @@ void _modinit(module_t *m)
 	service_bind_command(loveserv, &ls_help);
 }
 
-void _moddeinit(module_unload_intent_t intent)
+static void
+mod_deinit(const module_unload_intent_t intent)
 {
 	service_unbind_command(loveserv, &ls_admirer);
 	service_unbind_command(loveserv, &ls_rose);
@@ -318,8 +407,4 @@ void _moddeinit(module_unload_intent_t intent)
 		service_delete(loveserv);
 }
 
-/* vim:cinoptions=>s,e0,n0,f0,{0,}0,^0,=s,ps,t0,c3,+s,(2s,us,)20,*30,gs,hs
- * vim:ts=8
- * vim:sw=8
- * vim:noexpandtab
- */
+SIMPLE_DECLARE_MODULE_V1("contrib/ircd_loveserv", MODULE_UNLOAD_CAPABILITY_OK)
