@@ -7,30 +7,10 @@
 
 #include "atheme-compat.h"
 
-DECLARE_MODULE_V1
-(
-	"contrib/ns_forbid", false, _modinit, _moddeinit,
-	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
-);
-
 #define FORBID_EMAIL "noemail"
 
-static void ns_cmd_forbid(sourceinfo_t *si, int parc, char *parv[]);
-
-command_t ns_forbid = { "FORBID", "Disallows use of a nickname.", PRIV_USER_ADMIN, 3, ns_cmd_forbid, { .path = "contrib/forbid" } };
-
-void _modinit(module_t *m)
-{
-	service_named_bind_command("nickserv", &ns_forbid);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	service_named_unbind_command("nickserv", &ns_forbid);
-}
-
-static void make_forbid(sourceinfo_t *si, const char *account, const char *reason)
+static void
+make_forbid(sourceinfo_t *si, const char *account, const char *reason)
 {
 	myuser_t *mu;
 	mynick_t *mn = NULL;
@@ -82,7 +62,8 @@ static void make_forbid(sourceinfo_t *si, const char *account, const char *reaso
 	/* don't call hooks, hmm */
 }
 
-static void destroy_forbid(sourceinfo_t *si, const char *account)
+static void
+destroy_forbid(sourceinfo_t *si, const char *account)
 {
 	myuser_t *mu;
 	metadata_t *md;
@@ -90,7 +71,7 @@ static void destroy_forbid(sourceinfo_t *si, const char *account)
 	mu = myuser_find(account);
 	if (!mu)
 	{
-		command_fail(si, fault_nosuch_target, _("\2%s\2 is not registered."), account);
+		command_fail(si, fault_nosuch_target, STR_IS_NOT_REGISTERED, account);
 		return;
 	}
 
@@ -106,10 +87,11 @@ static void destroy_forbid(sourceinfo_t *si, const char *account)
 	wallops("%s unforbade the nickname \2%s\2.", get_oper_name(si), account);
 	command_success_nodata(si, "\2%s\2 is no longer forbidden.", entity(mu)->name);
 	/* no hooks here either, hmm */
-	object_unref(mu);
+	atheme_object_unref(mu);
 }
 
-static void ns_cmd_forbid(sourceinfo_t *si, int parc, char *parv[])
+static void
+ns_cmd_forbid(sourceinfo_t *si, int parc, char *parv[])
 {
 	const char *account;
 	const char *action;
@@ -120,7 +102,7 @@ static void ns_cmd_forbid(sourceinfo_t *si, int parc, char *parv[])
 	if (!account || !action)
 	{
 		command_fail(si, fault_needmoreparams, STR_INSUFFICIENT_PARAMS, "FORBID");
-		command_fail(si, fault_needmoreparams, "Syntax: FORBID <nickname> ON|OFF [reason]");
+		command_fail(si, fault_needmoreparams, _("Syntax: FORBID <nickname> ON|OFF [reason]"));
 		return;
 	}
 
@@ -143,8 +125,25 @@ static void ns_cmd_forbid(sourceinfo_t *si, int parc, char *parv[])
 	}
 }
 
-/* vim:cinoptions=>s,e0,n0,f0,{0,}0,^0,=s,ps,t0,c3,+s,(2s,us,)20,*30,gs,hs
- * vim:ts=8
- * vim:sw=8
- * vim:noexpandtab
- */
+static command_t ns_forbid = {
+	.name           = "FORBID",
+	.desc           = N_("Disallows use of a nickname."),
+	.access         = PRIV_USER_ADMIN,
+	.maxparc        = 3,
+	.cmd            = &ns_cmd_forbid,
+	.help           = { .path = "contrib/forbid" },
+};
+
+static void
+mod_init(module_t *const restrict m)
+{
+	service_named_bind_command("nickserv", &ns_forbid);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	service_named_unbind_command("nickserv", &ns_forbid);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/ns_forbid", MODULE_UNLOAD_CAPABILITY_OK)
