@@ -6,33 +6,12 @@
  *
  * Remember to give the user:fregister priv to any soper you want
  * to be able to use this command.
- *
  */
 
 #include "atheme-compat.h"
 
-DECLARE_MODULE_V1
-(
-	"contrib/ns_fregister", false, _modinit, _moddeinit,
-	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
-);
-
-static void ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[]);
-
-command_t ns_fregister = { "FREGISTER", "Registers a nickname on behalf of another user.", PRIV_USER_FREGISTER, 20, ns_cmd_fregister, { .path = "contrib/fregister" } };
-
-void _modinit(module_t *m)
-{
-	service_named_bind_command("nickserv", &ns_fregister);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	service_named_unbind_command("nickserv", &ns_fregister);
-}
-
-static void ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[])
+static void
+ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[])
 {
 	myuser_t *mu;
 	mynick_t *mn = NULL;
@@ -47,7 +26,8 @@ static void ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[])
 	if (!account || !pass || !email)
 	{
 		command_fail(si, fault_needmoreparams, STR_INSUFFICIENT_PARAMS, "FREGISTER");
-		command_fail(si, fault_needmoreparams, "Syntax: FREGISTER <account> <password> <email> [CRYPTPASS]");
+		command_fail(si, fault_needmoreparams, _("Syntax: FREGISTER <account> <password> <email> "
+		                                         "[CRYPTPASS] [HIDEMAIL] [NOOP] [NEVEROP]"));
 		return;
 	}
 
@@ -63,9 +43,12 @@ static void ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[])
 			uflags |= MU_NEVEROP;
 	}
 
-	if (!(uflags & MU_CRYPTPASS) && strlen(pass) > 32)
+	if (strlen(pass) > COMPAT_PASSLEN)
 	{
-		command_fail(si, fault_badparams, STR_INVALID_PARAMS, "FREGISTER");
+		if (uflags & MU_CRYPTPASS)
+			command_fail(si, fault_badparams, "The provided password hash is too long");
+		else
+			command_fail(si, fault_badparams, "The provided password is too long");
 		return;
 	}
 
@@ -119,8 +102,25 @@ static void ns_cmd_fregister(sourceinfo_t *si, int parc, char *parv[])
 	hook_call_user_verify_register(&req);
 }
 
-/* vim:cinoptions=>s,e0,n0,f0,{0,}0,^0,=s,ps,t0,c3,+s,(2s,us,)20,*30,gs,hs
- * vim:ts=8
- * vim:sw=8
- * vim:noexpandtab
- */
+static command_t ns_fregister = {
+	.name           = "FREGISTER",
+	.desc           = N_("Registers a nickname on behalf of another user."),
+	.access         = PRIV_USER_FREGISTER,
+	.maxparc        = 20,
+	.cmd            = &ns_cmd_fregister,
+	.help           = { .path = "contrib/fregister" },
+};
+
+static void
+mod_init(module_t *const restrict m)
+{
+	service_named_bind_command("nickserv", &ns_fregister);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	service_named_unbind_command("nickserv", &ns_fregister);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/ns_fregister", MODULE_UNLOAD_CAPABILITY_OK)
