@@ -1,42 +1,22 @@
 #include "atheme-compat.h"
-#include "conf.h"
-#include "datastream.h"
+
+#if (CURRENT_ABI_REVISION < 730000)
+#  include "conf.h"
+#  include "datastream.h"
+#endif
 
 #ifndef _WIN32
 
-DECLARE_MODULE_V1
-(
-	"contrib/on_db_save", false, _modinit, _moddeinit,
-	"",
-	"Atheme Development Group <http://www.atheme.org>"
-);
-
-static char *command = NULL;
-
-static void on_db_save(void *unused);
-
 static struct update_command_state {
 	connection_t *out, *err;
 	pid_t pid;
 	int running;
 } update_command_proc;
 
-void _modinit(module_t *m)
-{
-	hook_add_event("db_saved");
-	hook_add_db_saved(on_db_save);
+static char *command = NULL;
 
-	add_dupstr_conf_item("db_update_command", &conf_gi_table, 0, &command, NULL);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	hook_del_db_saved(on_db_save);
-
-	del_conf_item("db_update_command", &conf_gi_table);
-}
-
-static void update_command_finished(pid_t pid, int status, void *data)
+static void
+update_command_finished(pid_t pid, int status, void *data)
 {
 	if (!WIFEXITED(status) || WEXITSTATUS(status) != 0)
 		slog(LG_ERROR, "ERROR: Database update command failed with error %d", WEXITSTATUS(status));
@@ -44,7 +24,8 @@ static void update_command_finished(pid_t pid, int status, void *data)
 	update_command_proc.running = 0;
 }
 
-static void update_command_recvq_handler(connection_t *cptr, int err)
+static void
+update_command_recvq_handler(connection_t *cptr, int err)
 {
 	char buf[BUFSIZE];
 	int count;
@@ -66,17 +47,20 @@ static void update_command_recvq_handler(connection_t *cptr, int err)
 		slog(LG_DEBUG, "db update command stdout: %s", buf);
 }
 
-static void update_command_stdout_handler(connection_t *cptr)
+static void
+update_command_stdout_handler(connection_t *cptr)
 {
 	update_command_recvq_handler(cptr, 0);
 }
 
-static void update_command_stderr_handler(connection_t *cptr)
+static void
+update_command_stderr_handler(connection_t *cptr)
 {
 	update_command_recvq_handler(cptr, 1);
 }
 
-static void on_db_save(void *unused)
+static void
+on_db_save(void *unused)
 {
 	int stdout_pipes[2], stderr_pipes[2];
 	pid_t pid;
@@ -141,4 +125,23 @@ static void on_db_save(void *unused)
 	}
 }
 
+static void
+mod_init(module_t *const restrict m)
+{
+	hook_add_event("db_saved");
+	hook_add_db_saved(on_db_save);
+
+	add_dupstr_conf_item("db_update_command", &conf_gi_table, 0, &command, NULL);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	hook_del_db_saved(on_db_save);
+
+	del_conf_item("db_update_command", &conf_gi_table);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/on_db_save", MODULE_UNLOAD_CAPABILITY_OK)
+
 #endif
