@@ -12,28 +12,8 @@
 
 #include "atheme-compat.h"
 
-DECLARE_MODULE_V1
-(
-	"contrib/os_kill", false, _modinit, _moddeinit,
-	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
-);
-
-static void os_cmd_kill(sourceinfo_t *si, int parc, char *parv[]);
-
-command_t os_kill = { "KILL", "Kill a user with Services.", PRIV_OMODE, 2, os_cmd_kill, { .path = "contrib/kill" } };
-
-void _modinit(module_t *m)
-{
-	service_named_bind_command("operserv", &os_kill);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	service_named_unbind_command("operserv", &os_kill);
-}
-
-static void os_cmd_kill(sourceinfo_t *si, int parc, char *parv[])
+static void
+os_cmd_kill(sourceinfo_t *si, int parc, char *parv[])
 {
 	user_t *target;
 
@@ -54,3 +34,26 @@ static void os_cmd_kill(sourceinfo_t *si, int parc, char *parv[])
 
 	kill_user(si->service->me, target, "Requested: %s", parv[1]);
 }
+
+static command_t os_kill = {
+	.name           = "KILL",
+	.desc           = N_("Kill a user with Services."),
+	.access         = PRIV_OMODE,
+	.maxparc        = 2,
+	.cmd            = &os_cmd_kill,
+	.help           = { .path = "contrib/kill" },
+};
+
+static void
+mod_init(module_t *const restrict m)
+{
+	service_named_bind_command("operserv", &os_kill);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	service_named_unbind_command("operserv", &os_kill);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/os_kill", MODULE_UNLOAD_CAPABILITY_OK)
