@@ -1,55 +1,23 @@
 /*
- * Copyright (c) 2005-2007 Atheme Development Group
+ * Copyright (c) 2005-2016 Atheme Development Group
  * Rights to this code are as documented in doc/LICENSE.
  *
  * Autokline channels.
  *
+ * Default AKILL Time is based on the value of SET KLINETIME.
  */
 
 #include "atheme-compat.h"
 
-DECLARE_MODULE_V1
-(
-	"contrib/os_klinechan", false, _modinit, _moddeinit,
-	PACKAGE_STRING,
-	"Jilles Tjoelker <http://www.stack.nl/~jilles/irc/>"
-);
-
-static void os_cmd_klinechan(sourceinfo_t *si, int parc, char *parv[]);
-static void os_cmd_listklinechans(sourceinfo_t *si, int parc, char *parv[]);
-
-command_t os_klinechan = { "KLINECHAN", "Klines all users joining a channel.",
-			PRIV_MASS_AKILL, 3, os_cmd_klinechan, { .path = "contrib/klinechan" } };
-command_t os_listklinechans = { "LISTKLINECHAN", "Lists active K:line channels.", PRIV_MASS_AKILL, 1, os_cmd_listklinechans, { .path = "contrib/listklinechans" } };
-
-static void klinechan_check_join(hook_channel_joinpart_t *hdata);
-static void klinechan_show_info(hook_channel_req_t *hdata);
-
-void _modinit(module_t *m)
-{
-	service_named_bind_command("operserv", &os_klinechan);
-	service_named_bind_command("operserv", &os_listklinechans);
-	hook_add_event("channel_join");
-	hook_add_first_channel_join(klinechan_check_join);
-	hook_add_event("channel_info");
-	hook_add_channel_info(klinechan_show_info);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	service_named_unbind_command("operserv", &os_klinechan);
-	service_named_unbind_command("operserv", &os_listklinechans);
-	hook_del_channel_join(klinechan_check_join);
-	hook_del_channel_info(klinechan_show_info);
-}
-
-static void klinechan_check_join(hook_channel_joinpart_t *hdata)
+static void
+klinechan_check_join(hook_channel_joinpart_t *hdata)
 {
 	mychan_t *mc;
 	chanuser_t *cu = hdata->cu;
 	service_t *svs;
 	char reason[256];
 	const char *khost;
+	kline_t *k;
 
 	svs = service_find("operserv");
 	if (svs == NULL)
@@ -89,13 +57,14 @@ static void klinechan_check_join(hook_channel_joinpart_t *hdata)
 					cu->user->user, cu->user->host,
 					cu->chan->name);
 
-			kline_sts("*", "*", khost, 86400, reason);
+			k = kline_add("*", khost, reason, config_options.kline_time, "*");
 			cu->user->flags |= UF_KLINESENT;
 		}
 	}
 }
 
-static void klinechan_show_info(hook_channel_req_t *hdata)
+static void
+klinechan_show_info(hook_channel_req_t *hdata)
 {
 	metadata_t *md;
 	const char *setter, *reason;
@@ -120,7 +89,8 @@ static void klinechan_show_info(hook_channel_req_t *hdata)
 	command_success_nodata(hdata->si, "%s had \2automatic klines\2 enabled on it by %s on %s (%s)", hdata->mc->name, setter, strfbuf, reason);
 }
 
-static void os_cmd_klinechan(sourceinfo_t *si, int parc, char *parv[])
+static void
+os_cmd_klinechan(sourceinfo_t *si, int parc, char *parv[])
 {
 	char *target = parv[0];
 	char *action = parv[1];
@@ -136,7 +106,7 @@ static void os_cmd_klinechan(sourceinfo_t *si, int parc, char *parv[])
 
 	if (!(mc = mychan_find(target)))
 	{
-		command_fail(si, fault_nosuch_target, "\2%s\2 is not registered.", target);
+		command_fail(si, fault_nosuch_target, STR_IS_NOT_REGISTERED, target);
 		return;
 	}
 
@@ -192,13 +162,14 @@ static void os_cmd_klinechan(sourceinfo_t *si, int parc, char *parv[])
 	}
 }
 
-static void os_cmd_listklinechans(sourceinfo_t *si, int parc, char *parv[])
+static void
+os_cmd_listklinechans(sourceinfo_t *si, int parc, char *parv[])
 {
 	const char *pattern;
 	mowgli_patricia_iteration_state_t state;
 	mychan_t *mc;
 	metadata_t *md;
-	int matches = 0;
+	unsigned int matches = 0;
 
 	pattern = parc >= 1 ? parv[0] : "*";
 
@@ -214,10 +185,54 @@ static void os_cmd_listklinechans(sourceinfo_t *si, int parc, char *parv[])
 		}
 	}
 
-	logcommand(si, CMDLOG_ADMIN, "LISTKLINECHANS: \2%s\2 (\2%d\2 matches)", pattern, matches);
+	logcommand(si, CMDLOG_ADMIN, "LISTKLINECHANS: \2%s\2 (\2%u\2 matches)", pattern, matches);
+
 	if (matches == 0)
 		command_success_nodata(si, _("No K:line channels matched pattern \2%s\2"), pattern);
 	else
-		command_success_nodata(si, ngettext(N_("\2%d\2 match for pattern \2%s\2"),
-						    N_("\2%d\2 matches for pattern \2%s\2"), matches), matches, pattern);
+		command_success_nodata(si, ngettext(N_("\2%u\2 match for pattern \2%s\2"),
+						    N_("\2%u\2 matches for pattern \2%s\2"), matches), matches, pattern);
 }
+
+static command_t os_klinechan = {
+	.name           = "KLINECHAN",
+	.desc           = N_("Klines all users joining a channel for the duration set by SET KLINETIME."),
+	.access         = PRIV_MASS_AKILL,
+	.maxparc        = 3,
+	.cmd            = &os_cmd_klinechan,
+	.help           = { .path = "contrib/klinechan" },
+};
+
+static command_t os_listklinechans = {
+	.name           = "LISTKLINECHAN",
+	.desc           = N_("Lists active K:line channels."),
+	.access         = PRIV_MASS_AKILL,
+	.maxparc        = 1,
+	.cmd            = &os_cmd_listklinechans,
+	.help           = { .path = "contrib/listklinechans" },
+};
+
+static void
+mod_init(module_t *const restrict m)
+{
+	service_named_bind_command("operserv", &os_klinechan);
+	service_named_bind_command("operserv", &os_listklinechans);
+
+	hook_add_event("channel_join");
+	hook_add_first_channel_join(klinechan_check_join);
+
+	hook_add_event("channel_info");
+	hook_add_channel_info(klinechan_show_info);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	service_named_unbind_command("operserv", &os_klinechan);
+	service_named_unbind_command("operserv", &os_listklinechans);
+
+	hook_del_channel_join(klinechan_check_join);
+	hook_del_channel_info(klinechan_show_info);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/os_klinechan", MODULE_UNLOAD_CAPABILITY_OK)
