@@ -6,43 +6,23 @@
  */
 
 #include "atheme-compat.h"
-#include "datastream.h"
+
+#if (CURRENT_ABI_REVISION < 730000)
+#  include "datastream.h"
+#endif
 
 #ifndef _WIN32
 
-DECLARE_MODULE_V1
-(
-	"contrib/os_testproc", false, _modinit, _moddeinit,
-	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
-);
-
 struct testprocdata
 {
-	char dest[NICKLEN];
+	char dest[COMPAT_NICKLEN + 1];
 	connection_t *pip;
 };
 
 static struct testprocdata procdata;
 
-static void os_cmd_testproc(sourceinfo_t *si, int parc, char *parv[]);
-
-command_t os_testproc = { "TESTPROC", "Does something with child processes.",
-                        AC_NONE, 0, os_cmd_testproc, { .path = "contrib/testproc" } };
-
-void _modinit(module_t *m)
-{
-	service_named_bind_command("operserv", &os_testproc);
-}
-
-void _moddeinit(module_unload_intent_t intent)
-{
-	if (procdata.pip != NULL)
-		connection_close_soon(procdata.pip);
-	service_named_unbind_command("operserv", &os_testproc);
-}
-
-static void testproc_recvqhandler(connection_t *cptr)
+static void
+testproc_recvqhandler(connection_t *cptr)
 {
 	char buf[BUFSIZE];
 	int count;
@@ -69,7 +49,8 @@ static void testproc_recvqhandler(connection_t *cptr)
 		notice(service_find("operserv")->me->nick, u->nick, "%s", buf);
 }
 
-static void testproc_closehandler(connection_t *cptr)
+static void
+testproc_closehandler(connection_t *cptr)
 {
 	if (cptr != procdata.pip)
 	{
@@ -81,7 +62,8 @@ static void testproc_closehandler(connection_t *cptr)
 	procdata.pip = NULL;
 }
 
-static void os_cmd_testproc(sourceinfo_t *si, int parc, char *parv[])
+static void
+os_cmd_testproc(sourceinfo_t *si, int parc, char *parv[])
 {
 	int pipes[2];
 
@@ -129,10 +111,30 @@ static void os_cmd_testproc(sourceinfo_t *si, int parc, char *parv[])
 	}
 }
 
-#endif
+static command_t os_testproc = {
+	.name           = "TESTPROC",
+	.desc           = N_("Does something with child processes."),
+	.access         = AC_NONE,
+	.maxparc        = 0,
+	.cmd            = &os_cmd_testproc,
+	.help           = { .path = "contrib/testproc" },
+};
 
-/* vim:cinoptions=>s,e0,n0,f0,{0,}0,^0,=s,ps,t0,c3,+s,(2s,us,)20,*30,gs,hs
- * vim:ts=8
- * vim:sw=8
- * vim:noexpandtab
- */
+static void
+mod_init(module_t *const restrict m)
+{
+	service_named_bind_command("operserv", &os_testproc);
+}
+
+static void
+mod_deinit(const module_unload_intent_t intent)
+{
+	if (procdata.pip != NULL)
+		connection_close_soon(procdata.pip);
+
+	service_named_unbind_command("operserv", &os_testproc);
+}
+
+SIMPLE_DECLARE_MODULE_V1("contrib/os_testproc", MODULE_UNLOAD_CAPABILITY_OK)
+
+#endif
