@@ -18,7 +18,7 @@ DECLARE_MODULE_V1
 (
 	"infoserv/main", true, _modinit, _moddeinit,
 	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
+	VENDOR_STRING
 );
 
 struct logoninfo_ {
