@@ -13,7 +13,7 @@ DECLARE_MODULE_V1
 (
 	"nickserv/set", false, _modinit, _moddeinit,
 	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
+	VENDOR_STRING
 );
 
 void _modinit(module_t *m)
