@@ -16,7 +16,7 @@ DECLARE_MODULE_V1
 (
 	"nickserv/set_emailmemos", false, _modinit, _moddeinit,
 	PACKAGE_STRING,
-	"Atheme Development Group <http://www.atheme.org>"
+	VENDOR_STRING
 );
 
 mowgli_patricia_t **ns_set_cmdtree;
